@@ -37,14 +37,14 @@ __all__ = ['Agent', 'AlternateNumber', 'AlternateNumberSettings', 'Announcement'
            'ForwardingRuleDetails', 'ForwardingSetting', 'Greeting', 'HGCallPolicies', 'HGandCQ', 'HistoryType', 
            'HuntGroup', 'License', 'Location', 'LocationAddress', 'LocationCallParkSettings', 'MenuKey', 
            'MohMessageSetting', 'NoAnswer', 'Notification', 'NotificationRepeat', 'NotificationType', 
-           'OverflowAction', 'OverflowSetting', 'Paging', 'PeopleStatus', 'Person', 'PersonForwardingSetting', 
-           'PersonPlaceAgent', 'PersonSettingsApiChild', 'PersonType', 'Personality', 'PhoneNumber', 
-           'PhoneNumberType', 'Policy', 'QueueSettings', 'Recall', 'RecallHuntGroup', 'Record', 'RecordingState', 
-           'RecurWeekly', 'RecurYearlyByDate', 'RecurYearlyByDay', 'Recurrence', 'RedirectReason', 'Redirection', 
-           'RingPattern', 'Schedule', 'ScheduleDay', 'ScheduleMonth', 'ScheduleType', 'ScheduleWeek', 'SipAddress', 
-           'SipType', 'SiteType', 'StorageType', 'TelephonyCall', 'TelephonyEvent', 'TelephonyEventData', 
-           'TelephonyParty', 'Tokens', 'UnansweredCalls', 'UserBase', 'UserNumber', 'UserType', 'VoiceMailFax', 
-           'VoicemailCopyOfMessage', 'VoicemailEnabled', 'VoicemailEnabledWithGreeting', 'VoicemailFax', 
-           'VoicemailMessageStorage', 'VoicemailNotifications', 'VoicemailSettings', 'VoicemailTransferToNumber', 
-           'WaitMessageSetting', 'WaitMode', 'WebHook', 'WebHookCreate', 'WebHookEvent', 'WebHookResource', 
-           'WebHookStatus', 'WelcomeMessageSetting', ]
+           'OverflowAction', 'OverflowSetting', 'Paging', 'PagingAgent', 'PeopleStatus', 'Person', 
+           'PersonForwardingSetting', 'PersonPlaceAgent', 'PersonSettingsApiChild', 'PersonType', 'Personality', 
+           'PhoneNumber', 'PhoneNumberType', 'Policy', 'QueueSettings', 'Recall', 'RecallHuntGroup', 'Record', 
+           'RecordingState', 'RecurWeekly', 'RecurYearlyByDate', 'RecurYearlyByDay', 'Recurrence', 'RedirectReason', 
+           'Redirection', 'RingPattern', 'Schedule', 'ScheduleDay', 'ScheduleMonth', 'ScheduleType', 'ScheduleWeek', 
+           'SipAddress', 'SipType', 'SiteType', 'StorageType', 'TelephonyCall', 'TelephonyEvent', 
+           'TelephonyEventData', 'TelephonyParty', 'Tokens', 'UnansweredCalls', 'UserBase', 'UserNumber', 'UserType', 
+           'VoiceMailFax', 'VoicemailCopyOfMessage', 'VoicemailEnabled', 'VoicemailEnabledWithGreeting', 
+           'VoicemailFax', 'VoicemailMessageStorage', 'VoicemailNotifications', 'VoicemailSettings', 
+           'VoicemailTransferToNumber', 'WaitMessageSetting', 'WaitMode', 'WebHook', 'WebHookCreate', 'WebHookEvent', 
+           'WebHookResource', 'WebHookStatus', 'WelcomeMessageSetting', ]
